@@ -417,7 +417,7 @@ class LupusecAPI:
 
             # Make API-Call to update
             _LOGGER.debug("...make API-call with get_devices_async() to Lupusec System.")            
-            await LupusecAPI.get_devices_async()
+            await LupusecAPI.get_devices_async(self)
 
             _LOGGER.debug("...API-call finished. check response...")
             # Check response 
